TreeConfiguration class

Constructors

TreeConfiguration({TextStyle titleStyle = const TextStyle(), double nodeHeight = 36, Widget prefixIcon = const Icon(Icons.arrow_drop_up), Duration animatedDuration = const Duration(milliseconds: 150), bool showCheckbox = true, bool animatePrefixIcon = true})

Properties

animatedDuration ↔ Duration
getter/setter pair
animatePrefixIcon ↔ bool
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
isExpanded ↔ bool
getter/setter pair
isShowChild ↔ bool
getter/setter pair
nodeHeight ↔ double
getter/setter pair
prefixIcon ↔ Widget
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
showCheckbox ↔ bool
getter/setter pair
titleStyle ↔ TextStyle
getter/setter pair

Methods

copyWith({TextStyle? titleStyle, double? nodeHeight, Widget? prefixIcon, Duration? animatedDuration, bool? showCheckbox, bool? animatePrefixIcon}) → TreeConfiguration
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited